Module transmit

Module transmit 

Transmit structures and helpers.

Structs

DelayedChannel
A Transmit that will construct a channel message towards a TURN client or server.
DelayedMessage
A Transmit that will construct a STUN message towards a client with the relevant data.
TransmitBuild
A piece of data that needs to be built before it can be transmitted.

Traits

DelayedTransmitBuild
A trait for delaying building a byte sequence for transmission