Transmit structures and helpers.
Structs
- Delayed
Channel - A
Transmitthat will construct a channel message towards a TURN client or server. - Delayed
Message - A
Transmitthat will construct a STUN message towards a client with the relevant data. - Transmit
Build - A piece of data that needs to be built before it can be transmitted.
Traits
- Delayed
Transmit Build - A trait for delaying building a byte sequence for transmission